@@ -1,6 +1,9 @@
 package MooseX::NonMoose;
 BEGIN {
-  $MooseX::NonMoose::VERSION = '0.21';
+  $MooseX::NonMoose::AUTHORITY = 'cpan:DOY';
+}
+{
+  $MooseX::NonMoose::VERSION = '0.23';
 }
 use Moose::Exporter;
 # ABSTRACT: easy subclassing of non-Moose classes
@@ -17,7 +20,7 @@ my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
 sub init_meta {
     my $package = shift;
     my %options = @_;
-    my $meta = Class::MOP::class_of($options{for_class});
+    my $meta = Moose::Util::find_meta($options{for_class});
     Carp::cluck('Roles have no use for MooseX::NonMoose')
         if $meta && $meta->isa('Moose::Meta::Role');
     $package->$init_meta(@_);
@@ -27,6 +30,7 @@ sub init_meta {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -35,7 +39,7 @@ MooseX::NonMoose - easy subclassing of non-Moose classes
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -118,6 +122,11 @@ any class. For globref-based classes in particular, L<MooseX::GlobRef> will
 also allow Moose to work. For more information, see the C<032-moosex-insideout>
 and C<033-moosex-globref> tests bundled with this dist.
 
+=item * Modifying your class' C<@ISA> after an intial C<extends> call will potentially
+cause problems if any of those new entries in the C<@ISA> override the constructor.
+C<MooseX::NonMoose> wraps the nearest C<new()> method at the time C<extends>
+is called and will not see any other C<new()> methods in the @ISA hierarchy.
+
 =item * Completely overriding the constructor in a class using
 C<MooseX::NonMoose> (i.e. using C<sub new { ... }>) currently doesn't work,
 although using method modifiers on the constructor should work identically to
@@ -125,11 +134,8 @@ normal Moose classes.
 
 =back
 
-Please report any bugs through RT: email
-C<bug-moosex-nonmoose at rt.cpan.org>, or browse to
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-NonMoose>.
-
-=for Pod::Coverage   init_meta
+Please report any bugs to GitHub Issues at
+L<https://github.com/doy/moosex-nonmoose/issues>.
 
 =head1 SEE ALSO
 
@@ -154,34 +160,35 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item * MetaCPAN
 
-L<http://annocpan.org/dist/MooseX-NonMoose>
+L<https://metacpan.org/release/MooseX-NonMoose>
 
-=item * CPAN Ratings
+=item * Github
 
-L<http://cpanratings.perl.org/d/MooseX-NonMoose>
+L<https://github.com/doy/moosex-nonmoose>
 
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MooseX-NonMoose>
 
-=item * Search CPAN
+=item * CPAN Ratings
 
-L<http://search.cpan.org/dist/MooseX-NonMoose>
+L<http://cpanratings.perl.org/d/MooseX-NonMoose>
 
 =back
 
+=for Pod::Coverage   init_meta
+
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
