@@ -1,6 +1,9 @@
 package MooseX::NonMoose::InsideOut;
 BEGIN {
-  $MooseX::NonMoose::InsideOut::VERSION = '0.21';
+  $MooseX::NonMoose::InsideOut::AUTHORITY = 'cpan:DOY';
+}
+{
+  $MooseX::NonMoose::InsideOut::VERSION = '0.23';
 }
 use Moose::Exporter;
 # ABSTRACT: easy subclassing of non-Moose non-hashref classes
@@ -18,7 +21,7 @@ my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
 sub init_meta {
     my $package = shift;
     my %options = @_;
-    my $meta = Class::MOP::class_of($options{for_class});
+    my $meta = Moose::Util::find_meta($options{for_class});
     Carp::cluck('Roles have no use for MooseX::NonMoose')
         if $meta && $meta->isa('Moose::Meta::Role');
     $package->$init_meta(@_);
@@ -28,6 +31,7 @@ sub init_meta {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -36,7 +40,7 @@ MooseX::NonMoose::InsideOut - easy subclassing of non-Moose non-hashref classes
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -71,14 +75,13 @@ version 0.21
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
