@@ -1,11 +1,16 @@
 package MooseX::NonMoose::Meta::Role::Class;
 BEGIN {
-  $MooseX::NonMoose::Meta::Role::Class::VERSION = '0.21';
+  $MooseX::NonMoose::Meta::Role::Class::AUTHORITY = 'cpan:DOY';
+}
+{
+  $MooseX::NonMoose::Meta::Role::Class::VERSION = '0.23';
 }
 use Moose::Role;
-use List::MoreUtils qw(any);
 # ABSTRACT: metaclass trait for L<MooseX::NonMoose>
 
+use List::MoreUtils qw(any);
+use Module::Runtime qw(use_package_optimistically);
+
 
 has has_nonmoose_constructor => (
     is      => 'rw',
@@ -27,13 +32,32 @@ has constructor_name => (
     default => sub { shift->throw_error("No constructor name has been set") },
 );
 
+# XXX ugh, really need to fix this in moose
+around reinitialize => sub {
+    my $orig = shift;
+    my $class = shift;
+    my ($pkg) = @_;
+
+    my $meta = blessed($pkg) ? $pkg : Moose::Util::find_meta($pkg);
+
+    $class->$orig(
+        @_,
+        (map { $_->init_arg => $_->get_value($meta) }
+             grep { $_->has_value($meta) }
+                  map { $meta->meta->find_attribute_by_name($_) }
+                      qw(has_nonmoose_constructor
+                         has_nonmoose_destructor
+                         constructor_name)),
+    );
+};
+
 sub _determine_constructor_options {
     my $self = shift;
     my @options = @_;
 
     # if we're using just the metaclass trait, but not the constructor trait,
     # then suppress the warning about not inlining a constructor
-    my $cc_meta = Class::MOP::class_of($self->constructor_class);
+    my $cc_meta = Moose::Util::find_meta($self->constructor_class);
     return (@options, inline_constructor => 0)
         unless $cc_meta->can('does_role')
             && $cc_meta->does_role('MooseX::NonMoose::Meta::Role::Constructor');
@@ -225,10 +249,10 @@ around superclasses => sub {
             );
         }
 
-        Class::MOP::load_class($name, $opts);
+        use_package_optimistically($name, $opts ? $opts->{-version} : ());
 
         if (defined($cur_constructor_name)) {
-            my $meta = Class::MOP::class_of($name);
+            my $meta = Moose::Util::find_meta($name);
             $self->throw_error(
                 "You specified '$cur_constructor_name' as the constructor for "
               . "$name, but $name has no method by that name"
@@ -332,6 +356,7 @@ no Moose::Role;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -340,7 +365,7 @@ MooseX::NonMoose::Meta::Role::Class - metaclass trait for L<MooseX::NonMoose>
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -362,7 +387,7 @@ version 0.21
           for_class       => $options{for_class},
           metaclass_roles => ['MooseX::NonMoose::Meta::Role::Class'],
       );
-      return Class::MOP::class_of($options{for_class});
+      return Moose::Util::find_meta($options{for_class});
   }
 
 =head1 DESCRIPTION
@@ -373,14 +398,13 @@ L<MooseX::NonMoose> for more details.
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
